# Data and code for "A Library of Late Transition Metal Alloy Dielectric Functions for Nanophotonic Applications"

This dataset is related to the article "A Library of Late Transition Metal
Alloy Dielectric Functions for Nanophotonic Applications" by
Rahm, Tiburski et al., Advanced Functional Materials 2020, 2002122,
DOI: 10.1002/adfm.202002122


## Contents

* `raw_df`: Dielectric functions as procuded with GPAW calculation.
* `interpolated_df`: Dielectric functions in 10 at.-% intervals for
  all ten alloys. These are recommended to use for random alloys.
* `structures`: Atomic structures in `.xyz` format of all structures
  calculated in this work. The file is readable by, e.g.,
  Atomic Simulation Environment (ASE).
* `scripts`: Scripts for reproducing the data (see below).
* `auxiliary_data/expansion-coefficients.data`: Redlich-Kister expansion
  coefficients, used internally by `scripts/extract_dielectric_functions.py`
* `patch/gpaw-19.8.1-GLLBSCM.diff`: GLLBSC patch for extended metallic
  systems for GPAW version 19.8.1.


## Reproduction of the data

The data was produced with Python 3.6.7 and GPAW version 19.8.1,
using PAW setups 0.9.20000 and GLLBSC patched for extended metallic systems.
This patch is included (`patch/gpaw-19.8.1-GLLBSCM.diff`).
GPAW can be downloaded and the patch applied like so:
```
git clone -b 19.8.1 https://gitlab.com/gpaw/gpaw.git gpaw-19.8.1-GLLBSCM
cd gpaw-19.8.1-GLLBSCM
git apply ../gpaw-19.8.1-GLLBSCM.diff
```

The following versions were used for the packages that GPAW depends on:
* ASE 3.19.1
* Numpy 1.15.0
* Scipy 1.1.0
* Libxc 4.2.3

An example GPAW calculation for Au consist of following steps:

1. Calculate ground state:

       gpaw python scripts/calculate_ground_state.py structures/Au.xyz Au 241

   This creates files `gscalc-Au.out` and `gs-Au.gpw`. To reproduce the
   results in the paper, the last parameter (nk) should be adapted to
   the structure calculated. Specifically:

   * Pure elements: 241
   * L1_0 intermetallics: 261
   * L1_1 intermetallics: 161
   * L1_2 intermetallics: 281
   * Remaining structures (SQS): 61

2. Calculate dielectric function:

       gpaw python scripts/calculate_dielectric_function.py Au

   This creates files `dfcalc-Au.out` and `df-Au.data`. The data file
   corresponds to the dielectric function in `raw_df`.

An example for extracting an interpolated dielectric function at
any composition from the command line:

    python scripts/extract_dielectric_functions.py Ag Au 0.75

