from gpaw.response.df import DielectricFunction
import numpy as np
import argparse


def calculate_dielectric_function(tag):
    infile = 'gs-{}.gpw'.format(tag)
    txtfile = 'dfcalc-{}.out'.format(tag)
    datfile = 'df-{}.data'.format(tag)

    q_c = [0.0, 0.0, 0.0]
    xc = 'ALDA'

    kwargs = dict(calc=infile,
                  ecut=50,
                  eta=0.01,
                  domega0=0.05,
                  rate='eta',
                  txt=txtfile)

    df = DielectricFunction(**kwargs)
    atoms = df.chi0.calc.atoms
    atoms.calc = df.chi0.calc

    eps_nlfc, eps_lfc = df.get_dielectric_function(xc=xc, q_c=q_c,
                                                   filename=None)
    frequencies = df.get_frequencies()
    np.savetxt(datfile, np.stack((frequencies, eps_lfc.real, eps_lfc.imag)).T,
               fmt=['%16.8f', '%22.8f', '%22.8f'])


parser = argparse.ArgumentParser()
parser.add_argument('tag', type=str,
                    help='Tag to identify structure')
args = parser.parse_args()
calculate_dielectric_function(tag=args.tag)
